%%
close all
clear all

%% Functions
PHI_Phase =@(t,alpha,omega,shift_h,shift_v) sin(omega*t + shift_h)*(alpha + shift_v);
PHI_DOT=@(t,alpha,omega,shift_h,shift_v) cos(omega*t+shift_h)*(alpha+shift_v)*omega;
PHI_DOT_DOT=@(t,alpha,omega,shift_h,shift_v) -sin(omega*t+shift_h)*(alpha+shift_v)*omega^2;
addpath('..\..\HydroForceFunc');
load('PARAM')
load('DATA_H1LT_Added.mat')
load('DATA_H2LT_Added.mat')
%% Constants
set(groot,'defaulttextInterpreter','latex');
set(groot, 'defaultAxesTickLabelInterpreter','latex');
set(groot,'defaultLegendInterpreter','latex');
h = 0.1;
f = 0;
ROD = 0.476;
m1 = 1.43;
m2 = 2.395;
%% Phase shift
shift_phase1 = zeros(1,9);
shift_phase2 = zeros(1,9);
for i = 1:9 %
    shift_phase2(i) = acos(dot(DATA_H2LT_Added{2,i}(:,7),DATA_H2LT_Added{2,i}(:,4)) ./ (norm(DATA_H2LT_Added{2,i}(:,7))*norm(DATA_H2LT_Added{2,i}(:,4))));
    shift_phase1(i) = acos(dot(DATA_H1LT_Added{2,i}(:,7),DATA_H1LT_Added{2,i}(:,4)) ./ (norm(DATA_H1LT_Added{2,i}(:,7))*norm(DATA_H1LT_Added{2,i}(:,4))));
end

%% Vertical shift
shift_amp1 = zeros(1,9);
shift_amp2 = zeros(1,9);
for j = 1:9
    temp1 = find(DATA_H2LT_Added{2,j}(:,7)>max(DATA_H2LT_Added{2,j}(:,4)));
    temp2 = find(DATA_H2LT_Added{2,j}(:,7)<min(DATA_H2LT_Added{2,j}(:,4)));
    shift_amp2(1,j) = mean([(mean(DATA_H2LT_Added{2,j}(temp1,7))-max(DATA_H2LT_Added{2,j}(:,4))) abs((mean(DATA_H2LT_Added{2,j}(temp2,7))-min(DATA_H2LT_Added{2,j}(:,4))))]);
    temp1 = find(DATA_H1LT_Added{2,j}(:,7)>max(DATA_H1LT_Added{2,j}(:,4)));
    temp2 = find(DATA_H1LT_Added{2,j}(:,7)<min(DATA_H1LT_Added{2,j}(:,4)));
    shift_amp1(1,j) = mean([(mean(DATA_H1LT_Added{2,j}(temp1,7))-max(DATA_H1LT_Added{2,j}(:,4))) abs((mean(DATA_H1LT_Added{2,j}(temp2,7))-min(DATA_H1LT_Added{2,j}(:,4))))]);
end
%% Numerical derivatives
phi_dot1= cell(1,9);
phi_dot_dot1= cell(1,9);
phi_dot2= cell(1,9);
phi_dot_dot2= cell(1,9);
for i = 1:9
phi_dot1{1,i}(1,:) = diff(DATA_H1LT_Added{2,i}(:,7))/h;
phi_dot_dot1{1,i}(1,:) = diff(phi_dot1{1,i}(1,:))/h;
phi_dot2{1,i}(1,:) = diff(DATA_H2LT_Added{2,i}(:,7))/h;
phi_dot_dot2{1,i}(1,:) = diff(phi_dot2{1,i}(1,:))/h;
end
%% Phase shifter mathematical derivatives
j = 1;
p_1 = cell(1,9);
p_d1 = cell(1,9);
p_dd1 = cell(1,9);
p_2 = cell(1,9);
p_d2 = cell(1,9);
p_dd2 = cell(1,9);
for j = 1:9
    for i = 1:length(DATA_H2LT_Added{2,j}(:,7))
        p_2{1,j}(1,i) = PHI_Phase(DATA_H2LT_Added{2,j}(i,1),DATA_H2LT_Added{2,j}(1,2),DATA_H2LT_Added{2,j}(1,3),-shift_phase2(j),shift_amp2(j));
        p_d2{1,j}(1,i) = PHI_DOT(DATA_H2LT_Added{2,j}(i,1),DATA_H2LT_Added{2,j}(1,2),DATA_H2LT_Added{2,j}(1,3),-shift_phase2(j),shift_amp2(j));
        p_dd2{1,j}(1,i) = PHI_DOT_DOT(DATA_H2LT_Added{2,j}(i,1),DATA_H2LT_Added{2,j}(1,2),DATA_H2LT_Added{2,j}(1,3),-shift_phase2(j),shift_amp2(j));
    end
    for i = 1:length(DATA_H1LT_Added{2,j}(:,7))
        p_1{1,j}(1,i) = PHI_Phase(DATA_H1LT_Added{2,j}(i,1),DATA_H1LT_Added{2,j}(1,2),DATA_H1LT_Added{2,j}(1,3),-shift_phase1(j),shift_amp1(j));
        p_d1{1,j}(1,i) = PHI_DOT(DATA_H1LT_Added{2,j}(i,1),DATA_H1LT_Added{2,j}(1,2),DATA_H1LT_Added{2,j}(1,3),-shift_phase1(j),shift_amp1(j));
        p_dd1{1,j}(1,i) = PHI_DOT_DOT(DATA_H1LT_Added{2,j}(i,1),DATA_H1LT_Added{2,j}(1,2),DATA_H1LT_Added{2,j}(1,3),-shift_phase1(j),shift_amp1(j));
    end
end

%% Plot Ref, meas and phase shifted ref

f = f+1;
figure(f)
hold on
grid on

plot(DATA_H2LT_Added{2,1}(:,1),rad2deg(DATA_H2LT_Added{2,1}(:,4)),'r')
plot(DATA_H2LT_Added{2,1}(:,1),rad2deg(DATA_H2LT_Added{2,1}(:,7)),'b')
plot(DATA_H2LT_Added{2,1}(:,1),rad2deg(p_2{1,1}(1,:)),'g')
xlabel('Time [s]')
ylabel('Angle $\phi$ [$^\circ$]')
axis([11 22.5 -inf inf])
legend('$\phi_{ref}$','$\phi$','$\phi$ corrected','location','best')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\phi_phiref_comp.eps');
close
%% plot acceleration - numerical and 
i = 9;
f = f+1;
figure(f)
hold on
grid on
plot(DATA_H2LT_Added{2,9}(1:end-2,1),rad2deg(phi_dot_dot2{1,i}(1,:)),'b');
plot(DATA_H2LT_Added{2,9}(1:end-2,1),rad2deg(p_dd2{1,i}(1,1:end-2)),'r','linewidth',2)
xlabel('Time [s]')
ylabel('Angular acceleration, $\ddot{\phi}$ [$^\circ / s^2$]')
axis([20 50 -inf inf])
legend('Numerical acceleration','$\ddot{\phi}$ corrected','location','best')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\ddotphi_num_ddot_comp.eps');
close
%% Filter y
close all
windowSize = 5; 
b_w = (1/windowSize)*ones(1,windowSize);
a_f = 1;
filty1 = cell(1,9);
filty2 = cell(1,9);
for i = 1:9
    filty2{1,i}(1,:) = filtfilt(b_w,a_f,DATA_H2LT_Added{2,i}(:,11));
    filty1{1,i}(1,:) = filtfilt(b_w,a_f,DATA_H1LT_Added{2,i}(:,11));
end

%% Plot filter
f = f+1;
figure(f);
hold on
grid on
plot(DATA_H1LT_Added{2,9}(:,1),DATA_H1LT_Added{2,9}(:,11),'b:','linewidth',2)
plot(DATA_H1LT_Added{2,9}(:,1),filty1{1,9}(1,:),'b','linewidth',1.5)
plot(DATA_H2LT_Added{2,9}(:,1),DATA_H2LT_Added{2,9}(:,11),'r:','linewidth',2)
plot(DATA_H2LT_Added{2,9}(:,1),filty2{1,9}(1,:),'r','linewidth',1.5)
axis([14 23 -inf inf])
xlabel('Time [s]')
ylabel('Force Y [N]')
legend('H1LT','H1LT - filtered','H2LT','H2LT - filtered','location','best')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\filter_fy_comp.eps');
close

%% Vy
VY2 = cell(1,9);
AY2 = cell(1,9);
VY1 = cell(1,9);
AY1 = cell(1,9);
for i = 1:9
    VY2{1,i}(1,:) = p_d2{1,i}(1,:)*ROD;
    AY2{1,i}(1,:) = p_dd2{1,i}(1,:)*ROD;
    VY1{1,i}(1,:) = p_d1{1,i}(1,:)*ROD;
    AY1{1,i}(1,:) = p_dd1{1,i}(1,:)*ROD;
end

%%
FY_1 = @(Vy,Cd,N) Fy_l1(Vy,Cd,N)+Fy_l2(Vy,Cd,N);
FY_2 = @(Vy,Cd_l1,Cd_l2,N) Fy_l1(Vy,Cd_l1,N)+Fy_l2(Vy,Cd_l2,N);
FY_3 = @(Vy,Cd_ht1,Cd_ht2,Cd_l1,Cd_l2,N) Fy_ht1(Vy,Cd_ht1)+Fy_ht2(Vy,Cd_ht2)+Fy_l1(Vy,Cd_l1,N)+Fy_l2(Vy,Cd_l2,N);
FY_4 = @(Vy,Cd_ht1,Cd_ht2,Cd_l1,Cd_l2,N) Fy_ht1(Vy,Cd_ht1)+Fy_ht2(Vy,Cd_ht2)+Fy_l1(Vy,Cd_l1,N)+Fy_l2(Vy,Cd_l2,N);
FY_5 = @(Vy,Cd_ht2,Cd_l1,Cd_l2,N) Fy_ht2(Vy,Cd_ht2)+Fy_l1(Vy,Cd_l1,N)+Fy_l2(Vy,Cd_l2,N);
FY_6 = @(Vy,Cd_y,N) Fy_cyl(Vy,Cd_y,N);

MA2 = cell(1,9);
MA1 = cell(1,9);
for i = 1:9
    MA2{1,i}(1,:) = m2*AY2{1,i}(1,:);
	MA1{1,i}(1,:) = m1*AY1{1,i}(1,:);
end

%%
load('C:\Users\garde\Dropbox\Prosjektoppgave - Snake Robot\MATLAB\Experiments\v2\Results\Resultino\HYDRO_P_EXP_ang.mat')
load('C:\Users\garde\Dropbox\Prosjektoppgave - Snake Robot\MATLAB\Experiments\v2\Results\Resultino\HYDRO_P_EXP.mat')
%HYDRO_P_EXP_ang = HYDRO_P_EXP;


%%
FY1= cell(2,9);
FY2 = cell(2,9);
for i = 1:9
    for j = 1:length(VY2{1,i}(1,:))
        FY2{1,i}(1,j) = FY_4(VY2{1,i}(1,j),HYDRO_P_EXP_ang{2,4}(1,1),HYDRO_P_EXP_ang{2,4}(1,2),HYDRO_P_EXP_ang{2,4}(1,3),HYDRO_P_EXP_ang{2,4}(1,4),2);
        FY2{2,i}(1,j) = FY_1(VY2{1,i}(1,j),HYDRO_P_EXP_ang{2,1}(1,1),2);
    end
     for j = 1:length(VY1{1,i}(1,:))
        FY1{1,i}(1,j) = FY_4(VY1{1,i}(1,j),HYDRO_P_EXP_ang{2,4}(1,1),HYDRO_P_EXP_ang{2,4}(1,2),HYDRO_P_EXP_ang{2,4}(1,3),HYDRO_P_EXP_ang{2,4}(1,4),1);
        FY1{2,i}(1,j) = FY_1(VY1{1,i}(1,j),HYDRO_P_EXP_ang{2,1}(1,1),1);
    end
    
end

%%
% 1=tid, 2=alpha, 3=omega, 4=phi_ref, 5= phi_ref_dot, 6=phi_ref_dot_dot,
% 7=phi, 8=phi_dot, 9=phi_dot_dot, 10=Fx, 11=Fy, 12=Fz, 13=Tx, 14=Ty, 15=Tz

load('BUOY_H1LT.mat');
B1 = mean(mean(BUOY_H1LT));
ADDED_m1 = cell(1,9);
ADDED_m1_f1 = cell(1,9);
ADDED_m_no_a1 = cell(1,9);
test1 = cell(1,9);

load('BUOY_H2LT.mat');
B2 = mean(mean(BUOY_H2LT));
ADDED_m2 = cell(1,9);
ADDED_m2_f1 = cell(1,9);
ADDED_m2_noHT = cell(1,9);
ADDED_m1_noHT = cell(1,9);
test2 = cell(1,9);
%%
for i = 1:9
    for j = 1:500%length(DATA_H2LT_Added{2,i}(:,11))
        test2{1,i}(1,j) =B2*sin(DATA_H2LT_Added{2,i}(j,7))-MA2{1,i}(1,j)+FY2{1,i}(1,j);
        ADDED_m2{1,i}(1,j) = -filty2{1,i}(1,j)+MA2{1,i}(1,j)+FY2{1,i}(1,j)+B2*sin(DATA_H2LT_Added{2,i}(j,7));%-0.4911*p_dd2{1,i}(1,j);
        ADDED_m2_f1{1,i}(1,j) = -filty2{1,i}(1,j)+MA2{1,i}(1,j)+FY2{2,i}(1,j)+B2*sin(DATA_H2LT_Added{2,i}(j,7));%-0.4911*p_dd2{1,i}(1,j);
        ADDED_m2_noHT{1,i}(1,j) = ADDED_m2{1,i}(1,j)-0.4911*p_dd2{1,i}(1,j);
    end
    for j = 1:500%length(DATA_H1LT_Added{2,i}(:,11))
        test1{1,i}(1,j) =B1*sin(DATA_H1LT_Added{2,i}(j,7))-MA1{1,i}(1,j)+FY1{1,i}(1,j);
        ADDED_m1{1,i}(1,j) = -filty1{1,i}(1,j)+MA1{1,i}(1,j)+FY1{1,i}(1,j)+B1*sin(DATA_H1LT_Added{2,i}(j,7));%-0.4911*p_dd1{1,i}(1,j);
        ADDED_m1_f1{1,i}(1,j) = -filty1{1,i}(1,j)+MA1{1,i}(1,j)+FY1{2,i}(1,j)+B1*sin(DATA_H1LT_Added{2,i}(j,7));%-0.4911*p_dd1{1,i}(1,j);
        ADDED_m1_noHT{1,i}(1,j) = ADDED_m1{1,i}(1,j)-0.4911*p_dd1{1,i}(1,j);
    end
end
%% Plot Fy, MA, Fdrag, Buoy
i = 9;
f = f+1;
figure(f)
hold on
grid on
plot(DATA_H2LT_Added{2,i}(:,1),filty2{1,i}(1,:),'linewidth',1.5)
plot(DATA_H2LT_Added{2,i}(:,1),MA2{1,i}(1,:))
plot(DATA_H2LT_Added{2,i}(:,1),FY2{1,i}(1,:))
plot(DATA_H2LT_Added{2,i}(:,1),B2*sin(DATA_H2LT_Added{2,i}(:,7)))
%plot(DATA_H2LT_Added{2,i}(:,1),0.4911*p_dd2{1,i}(1,:))
%plot(DATA_H2LT_Added{2,i}(1:500,1),ADDED_m2{1,i}(1,:))
%legend('$f_y$','$ma$','$f_{D}$','$f_B$','$f_{added,HT}$','$f_{added,L}$','location','best')
legend('$f_y$','$ma$','$f_{D}$','$f_B$','location','best')
axis([18 29 -inf inf])
xlabel('Time [s]')
ylabel('Force Y [N]')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\meas_ma_drag_buoy_comp.eps');
%close
%%



added_teo1 = cell(1,9);
added_teo2 = cell(1,9);

for i = 1:9
    for j = 1:500%length(p_dd2{1,i}(1,:))
        
        added_teo2{1,i}(1,j) = rho*p_dd2{1,i}(1,j)*((a*b*2*l*pi)*2);
    end
    
    for j = 1:500%length(p_dd1{1,i}(1,:))
        
        added_teo1{1,i}(1,j) = rho*p_dd1{1,i}(1,j)*((a*b*2*l*pi));
    end
end
GARD = zeros(1,9);
for i = 1:9
GARD(i) = lsqnonneg([added_teo1{1,i}(1,:)' ; added_teo2{1,i}(1,:)'],[ADDED_m1{1,i}(1,:)' ; ADDED_m2{1,i}(1,:)']);
end

ind1 = 1;
ind2 = 1;
ind3 = 1;
ind4 =1;
added_h2 = 0;
added_h2_noHT = 0;
added_h2_f1 = 0;
added_h1 = 0;
added_h1_noHT = 0;
added_h1_f1 = 0;
added_teo_h1 = 0;
added_teo_h2 = 0;
added_teo_h1_sim = 0;
added_teo_h2_sim = 0;
a_1 = 0;
a_2 = 0;

for i = 1:9
    for j = 1:500%length(ADDED_m2{1,i}(1,:))
        added_h2(ind1) = ADDED_m2{1,i}(1,j);
        added_h2_noHT(ind1) = ADDED_m2_noHT{1,i}(1,j);
        added_h2_f1(ind1) = ADDED_m2_f1{1,i}(1,j);
        
        a_1(ind1) = p_dd1{1,i}(1,j);
        a_2(ind1) = p_dd2{1,i}(1,j);
        ind1 = ind1+1;
    end

    for j = 1:500%length(ADDED_m1{1,i}(1,:))
        added_h1(ind2) = ADDED_m1{1,i}(1,j);
        added_h1_noHT(ind2) = ADDED_m1_noHT{1,i}(1,j);
        added_h1_f1(ind2) = ADDED_m1_f1{1,i}(1,j);
        ind2 = ind2+1;
    end
    for j = 1:500%length(added_teo2{1,i}(1,:))
        added_teo_h2(ind3) = added_teo2{1,i}(1,j);
        added_teo_h2_sim(ind3) = rho*(2.670*10^-3)*p_dd2{1,i}(1,j);
        ind3 = ind3 + 1;
    end
    
    for j = 1:500%length(added_teo1{1,i}(1,:))
       
        added_teo_h1(ind4) = added_teo1{1,i}(1,j);
        added_teo_h1_sim(ind4) = rho*(1.893*10^-3)*p_dd2{1,i}(1,j);
        ind4 = ind4 + 1;
    end
end
%%


LSQ_h1 = lsqnonneg(added_teo_h1',added_h1')
LSQ_h2 = lsqnonneg(added_teo_h2',added_h2')

LSQ_h1_noHT = lsqnonneg(added_teo_h1',added_h1_noHT')
LSQ_h2_noHT = lsqnonneg(added_teo_h2',added_h2_noHT')

LSQ_h1_f1 = lsqnonneg(added_teo_h1',added_h1_f1')
LSQ_h2_f1 = lsqnonneg(added_teo_h2',added_h2_f1')

HENRIK1 = [added_teo_h1' ; added_teo_h2'];
HENRIK2 = [added_h1' ; added_h2'];

HENRIK1_sim = [added_teo_h1_sim' ; added_teo_h2_sim'];
HENRIK2_sim = [added_h1' ; added_h2'];

HENRIK1_sim_f1 = [added_teo_h1_sim' ; added_teo_h2_sim'];
HENRIK2_sim_f1 = [added_h1_f1' ; added_h2_f1'];

HENRIK1_noHT = [added_teo_h1' ; added_teo_h2'];
HENRIK2_noHT = [added_h1_noHT' ; added_h2_noHT'];

HENRIK1_f1 = [added_teo_h1' ; added_teo_h2'];
HENRIK2_f1 = [added_h1_f1' ; added_h2_f1'];


LSQ_tot = lsqnonneg(HENRIK1,HENRIK2)
LSQ_tot_sim = lsqnonneg(HENRIK1_sim,HENRIK2_sim)
LSQ_tot_sim_f1 = lsqnonneg(HENRIK1_sim_f1,HENRIK2_sim_f1)
LSQ_tot_noHT = lsqnonneg(HENRIK1_noHT,HENRIK2_noHT)
LSQ_tot_f1 = lsqnonneg(HENRIK1_f1,HENRIK2_f1)
%non_dim2 = lsqnonneg(a_2',added_h2')
%non_dim1 = lsqnonneg(a_1',added_h1')
%non_dim_l = lsqnonneg(a_1',(added_h2'-added_h1'))
%%
f = f+1;
i = 2;
figure(f)
hold on
grid on
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*LSQ_tot)
%plot(HENRIK1_sim(1+500*i:500+500*i)*LSQ_tot_sim)
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
axis([10 40 -inf 1.2])
xlabel('Time [s]')
ylabel('$\hat{f}_A$ [N]')
legend('Experimental','Estimated')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\sysid\added_h1_a10_w80.eps');

f = f+1;
i = 11;
figure(f)
hold on
grid on
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*LSQ_tot)
%plot(HENRIK1_sim(1+500*i:500+500*i)*LSQ_tot_sim)
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
axis([10 40 -inf 1.8])
xlabel('Time [s]')
ylabel('$\hat{f}_A$ [N]')
legend('Experimental','Estimated')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\sysid\added_h2_a10_w80.eps');
%%
f = f+1;
i = 4;
figure(f)
hold on
grid on
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*LSQ_tot)
%plot(HENRIK1_sim(1+500*i:500+500*i)*LSQ_tot_sim)
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
axis([10 40 -inf inf])
xlabel('Time [s]')
ylabel('$\hat{f}_A$ [N]')
legend('Experimental','Estimated')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\sysid\added_h1_a15_w70.eps');
%%
f = f+1;
i = 13;
figure(f)
hold on
grid on
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*LSQ_tot)
%plot(HENRIK1_sim(1+500*i:500+500*i)*LSQ_tot_sim)
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
axis([10 40 -inf inf])
xlabel('Time [s]')
ylabel('$\hat{f}_A$ [N]')
legend('Experimental','Estimated')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\sysid\added_h2_a15_w70.eps');

%%
f = f+1;
i = 8;
figure(f)
hold on
grid on
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*LSQ_tot)
%plot(HENRIK1_sim(1+500*i:500+500*i)*LSQ_tot_sim)
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
axis([10 40 -inf inf])
xlabel('Time [s]')
ylabel('$\hat{f}_A$ [N]')
legend('Experimental','Estimated')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\sysid\added_h1_a20_w80.eps');
%%
f = f+1;
i = 17;
figure(f)
hold on
grid on
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*LSQ_tot)
%plot(HENRIK1_sim(1+500*i:500+500*i)*LSQ_tot_sim)
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
axis([10 40 -inf inf])
xlabel('Time [s]')
ylabel('$\hat{f}_A$ [N]')
legend('Experimental','Estimated')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\sysid\added_h2_a20_w80.eps');
%%
f = f+1;
i = 1;
figure(f)
hold on
grid on
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
i = 4;
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
i = 7;
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
axis([0 50 -2.5 2.5])
xlabel('Time [s]')
ylabel('$\hat{f}_A$ [N]')
legend('$\alpha = 10$, $\omega = 70$','$\alpha = 15$, $\omega = 70$','$\alpha = 20$, $\omega = 70$','location','best')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\res_h1_w70.eps');

%%
f = f+1;
i = 10;
figure(f)
hold on
grid on
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
i = 13;
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
i = 16;
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
xlabel('Time [s]')
ylabel('$\hat{f}_A$ [N]')
axis([0 50 -2.5 2.5])
legend('$\alpha = 10$, $\omega = 70$','$\alpha = 15$, $\omega = 70$','$\alpha = 20$, $\omega = 70$','location','best')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\res_h2_w70.eps');
%%
f = f+1;
i = 8;
figure(f)
hold on
grid on
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*LSQ_tot)
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*1.2674)
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*1.3601)
xlabel('Time [s]')
ylabel('$\hat{f}_A$ [N]')

axis([23 38 -1.9 1.9])
legend('$f_A$ - Measured','$f_A$ - Experimental $C_A$','$f_A$ - Simulation $C_A$','$f_A$ - Simulation $C_{A,y}$','location','best')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\sysid\comp_exp_sim_h1.eps');

%%
f = f+1;
i = 17;
figure(f)
hold on
grid on
plot((1:500)/10,HENRIK2(1+500*i:500+500*i))
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*LSQ_tot)
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*1.2674)
plot((1:500)/10,HENRIK1(1+500*i:500+500*i)*1.3601)
xlabel('Time [s]')
ylabel('$\hat{f}_A$ [N]')
axis([24 37.5 -2.8 2.8])
legend('$f_A$ - Measured','$f_A$ - Experimental $C_A$','$f_A$ - Simulation $C_A$','$f_A$ - Simulation $C_{A,y}$','location','best')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\exp2\added_mass\sysid\comp_exp_sim_h2.eps');

%%
% %%
% close all
% f = f+1;
% figure(f)
% i = 9;
% hold on
% grid on
% plot(ADDED_m1{1,i}(1,:))
% plot(ADDED_m2{1,i}(1,:))
% f = f+1;
% figure(f)
% plot(p_dd1{1,i}(1,:))
% hold on
% plot(p_dd2{1,i}(1,:))
% %%
% for i = 1:9
% f = f+1;
% figure(f)
% hold on
% plot(ADDED_m1{1,i}(1,1:500)')
% plot(added_teo1{1,i}(1,:)')
% end
% %% 
% f = f+1;
% figure(f)
% hold on
% plot(ADDED_m2{1,9}(1,1:500))
% plot(ADDED_m1{1,9}(1,1:500))
% hold on
% legend('2','1')
% %plot(added_teo2{1,1}(1,1:500))
% %plot(added_teo1{1,1}(1,1:500))
% 
% %%
% f = f+1;
% figure(f)
% hold on
% plot(DATA_H1LT_Added{2,1}(:,11))
% plot(DATA_H2LT_Added{2,1}(:,11))
% legend('1','2')
% 
% %%
% f = f+1;
% figure(f)
% hold on
% plot(MA1{1,1}(1,:))
% plot(MA2{1,1}(1,:))
% legend('1','2')
% 
% %%
% f = f+1;
% figure(f)
% hold on
% plot(FY1{1,1}(1,:))
% plot(FY2{1,1}(1,:))
% legend('1','2')
% 
% %%
% f = f+1;
% figure(f)
% hold on
% plot(DATA_H1LT_Added{2,1}(:,7))
% plot(DATA_H2LT_Added{2,1}(:,7))
% legend('1','2')
% %%
% f = f+1;
% figure(f)
% hold on
% plot(DATA_H2LT_Added{2,9}(:,4))
% plot(DATA_H2LT_Added{2,9}(:,7))