%%
clear all;
close all;


%% Plot config
set(groot,'defaulttextInterpreter','latex');
set(groot, 'defaultAxesTickLabelInterpreter','latex');
set(groot,'defaultLegendInterpreter','latex');
f = 0;

%%
load('H1LT_0deg_Fx.mat')
load('H1LT_0deg_Vx.mat')
load('H2LT_0deg_Fx.mat')
load('H2LT_0deg_Vx.mat')

%% Velocity/Force plot
f = f+1;
figure(f)
hold on
grid on
plot(H1LT_0deg_Vx(1,1),H1LT_0deg_Fx(1,1),'rx')
plot(H2LT_0deg_Vx(1,1),H2LT_0deg_Fx(1,1),'bx')
legend OFF
plot(H1LT_0deg_Vx,H1LT_0deg_Fx,'rx')
plot(H2LT_0deg_Vx,H2LT_0deg_Fx,'bx')
plot(mean(H1LT_0deg_Vx),mean(H1LT_0deg_Fx),'r-.')
plot(mean(H2LT_0deg_Vx),mean(H2LT_0deg_Fx),'b-.')
legend('H1LT','H2LT')
xlabel('Velocity [m/s]')
ylabel('Force X [N]')
tightfig(f);
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\experiments\v1_0deg\0deg_vx_fx.eps');
close

%% Weight/Force
f = f+1;
figure(f)
hold on
grid on
plot(1,H1LT_0deg_Fx(1,1),'rx')
plot(2,H2LT_0deg_Fx(1,1),'bx')
legend OFF
for i = 1:length(H1LT_0deg_Fx(1,:))
plot(i,H1LT_0deg_Fx(:,i),'rx')
end

for i = 1:length(H2LT_0deg_Fx(1,:))
plot(i+1,H2LT_0deg_Fx(:,i),'bx')
end
plot(1:length(H1LT_0deg_Fx(1,:)),mean(H1LT_0deg_Fx),'r-.')
plot(2:length(H2LT_0deg_Fx(1,:))+1,mean(H2LT_0deg_Fx),'b-.')
xlabel('Weight [g]')
ylabel('Force [N]')
set(gca,'XTick',[1 2 3 4 5 6 7 8],'XTickLabel',{'25' '50' '75' '100' '125' '150' '175' '200'})
legend('H1LT','H2LT')
tightfig(f);
axis([0 9 -1 0])
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\experiments\v1_0deg\0deg_weight_fx.eps');
close

%% Weight/Velocity
f = f+1;
figure(f)
hold on
grid on
plot(1,H1LT_0deg_Vx(1,1),'rx')
plot(2,H2LT_0deg_Vx(1,1),'bx')
legend OFF
for i = 1:length(H1LT_0deg_Vx(1,:))
plot(i,H1LT_0deg_Vx(:,i),'rx')
end

for i = 1:length(H2LT_0deg_Vx(1,:))
plot(i+1,H2LT_0deg_Vx(:,i),'bx')
end
plot(1:8,mean(H1LT_0deg_Vx),'r-.')
plot(2:6,mean(H2LT_0deg_Vx),'b-.')
xlabel('Weight [g]')
ylabel('Veloctiy [m/s]')
set(gca,'XTick',[1 2 3 4 5 6 7 8],'XTickLabel',{'25' '50' '75' '100' '125' '150' '175' '200'})
legend('H1LT','H2LT')
tightfig(f);
axis([0 9 0 1])
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\experiments\v1_0deg\0deg_weight_vx.eps');
close

%%
addpath('..\..\HydroForceFunc');
load('PARAM')
load('HYDRO_P_EXP')
FX_1 = @(Vx,Cf,N) Fx_l1(Vx,Cf,N)+Fx_l2(Vx,Cf,N);
FX_2 = @(Vx,Cf_l1,Cf_l2,N) Fx_l1(Vx,Cf_l1,N)+Fx_l2(Vx,Cf_l2,N);
FX_3 = @(Vx,Cf_ht1,Cf_ht2,Cf_l1,Cf_l2,N) Fx_ht1(Vx,Cf_ht1)+Fx_ht2(Vx,Cf_ht2)+Fx_l1(Vx,Cf_l1,N)+Fx_l2(Vx,Cf_l2,N);
FX_4 = @(Vx,Vy,Cf_ht1,Cf_ht2,Cf_l1,Cf_l2,Cf_y1,Cf_y2,N) Fx_ht1(Vx,Cf_ht1)+Fx_ht2(Vx,Cf_ht2)+Fx_l1(Vx,Cf_l1,N)+Fx_l2(Vx,Cf_l2,N)+Fx_y1(Vy,Cf_y1)+Fx_y2(Vy,Cf_y2);
FX_5 = @(Vx,Vy,Cf_ht2,Cf_l1,Cf_l2,Cf_y2,N) Fx_ht2(Vx,Cf_ht2)+Fx_l1(Vx,Cf_l1,N)+Fx_l2(Vx,Cf_l2,N)+Fx_y2(Vy,Cf_l2);
FX_6 = @(Vx,Cd_x) Fx_cyl(Vx,Cd_x);



%%
TEOX_1_H1LT = zeros(1,8);
TEOX_2_H1LT = zeros(1,8);
TEOX_3_H1LT = zeros(1,8);
TEOX_4_H1LT = zeros(1,8);
TEOX_5_H1LT = zeros(1,8);
TEOX_6_H1LT = zeros(1,8);
for i = 1:8
    TEOX_1_H1LT(1,i) = FX_1(mean(H1LT_0deg_Vx(:,i)),HYDRO_P_EXP{1,1}(1,1),1);
    TEOX_2_H1LT(1,i) = FX_2(mean(H1LT_0deg_Vx(:,i)),HYDRO_P_EXP{1,2}(1,1),HYDRO_P_EXP{1,2}(1,2),1);
    TEOX_3_H1LT(1,i) = FX_3(mean(H1LT_0deg_Vx(:,i)),HYDRO_P_EXP{1,3}(1,1),HYDRO_P_EXP{1,3}(1,2),HYDRO_P_EXP{1,3}(1,3),HYDRO_P_EXP{1,3}(1,4),1);
    TEOX_4_H1LT(1,i) = FX_4(mean(H1LT_0deg_Vx(:,i)),0,HYDRO_P_EXP{1,4}(1,1),HYDRO_P_EXP{1,4}(1,2),HYDRO_P_EXP{1,4}(1,3),HYDRO_P_EXP{1,4}(1,4),HYDRO_P_EXP{1,4}(1,5),HYDRO_P_EXP{1,4}(1,6),1);
    TEOX_5_H1LT(1,i) = FX_5(mean(H1LT_0deg_Vx(:,i)),0,HYDRO_P_EXP{1,5}(1,1),HYDRO_P_EXP{1,5}(1,2),HYDRO_P_EXP{1,5}(1,3),HYDRO_P_EXP{1,5}(1,4),1);
    TEOX_6_H1LT(1,i) = FX_6(mean(H1LT_0deg_Vx(:,i)),HYDRO_P_EXP{1,6}(1,1));
end
TEOX_1_H2LT = zeros(1,5);
TEOX_2_H2LT = zeros(1,5);
TEOX_3_H2LT = zeros(1,5);
TEOX_4_H2LT = zeros(1,5);
TEOX_5_H2LT = zeros(1,5);
TEOX_6_H2LT = zeros(1,5);
for i = 1:5
    TEOX_1_H2LT(1,i) = FX_1(mean(H2LT_0deg_Vx(:,i)),HYDRO_P_EXP{1,1}(1,1),2);
    TEOX_2_H2LT(1,i) = FX_2(mean(H2LT_0deg_Vx(:,i)),HYDRO_P_EXP{1,2}(1,1),HYDRO_P_EXP{1,2}(1,2),2);
    TEOX_3_H2LT(1,i) = FX_3(mean(H2LT_0deg_Vx(:,i)),HYDRO_P_EXP{1,3}(1,1),HYDRO_P_EXP{1,3}(1,2),HYDRO_P_EXP{1,3}(1,3),HYDRO_P_EXP{1,3}(1,4),2);
    TEOX_4_H2LT(1,i) = FX_4(mean(H2LT_0deg_Vx(:,i)),0,HYDRO_P_EXP{1,4}(1,1),HYDRO_P_EXP{1,4}(1,2),HYDRO_P_EXP{1,4}(1,3),HYDRO_P_EXP{1,4}(1,4),HYDRO_P_EXP{1,4}(1,5),HYDRO_P_EXP{1,4}(1,6),2);
    TEOX_5_H2LT(1,i) = FX_5(mean(H2LT_0deg_Vx(:,i)),0,HYDRO_P_EXP{1,5}(1,1),HYDRO_P_EXP{1,5}(1,2),HYDRO_P_EXP{1,5}(1,3),HYDRO_P_EXP{1,5}(1,4),2);
    TEOX_6_H2LT(1,i) = FX_6(mean(H2LT_0deg_Vx(:,i)),HYDRO_P_EXP{1,6}(1,1));
end

%% Velocity/Force plot sim/exp compare
load('..\..\Simulations_master\v3\H1LT_sim_v3.mat')
load('..\..\Simulations_master\v3\H2LT_sim_v3.mat')
%%
f = f+1;
figure(f)
hold on
grid on
plot(mean(H1LT_0deg_Vx),mean(H1LT_0deg_Fx),'r')
plot(H1LT_sim_v3(1:50,2),H1LT_sim_v3(1:50,4),'r-.')
plot(mean(H2LT_0deg_Vx),mean(H2LT_0deg_Fx),'b')
plot(H2LT_sim_v3(1:50,2),H2LT_sim_v3(1:50,4),'b-.')
legend('Exp - H1LT','Sim - H1LT','Exp - H1LT','Sim - H2LT')
xlabel('Velocity [m/s]')
ylabel('Force X [N]')
tightfig(f);
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\sysid\comp_sim_exp_v1_0deg.eps');
close

%% theta = 0, comp exp and sysid H1LT
f = f+1;
figure(f)
hold on
grid on
plot(H1LT_0deg_Vx(1,1),H1LT_0deg_Fx(1,1),'rx')
plot(mean(H1LT_0deg_Vx),TEOX_1_H1LT)
plot(mean(H1LT_0deg_Vx),TEOX_2_H1LT)
plot(mean(H1LT_0deg_Vx),TEOX_3_H1LT)
plot(mean(H1LT_0deg_Vx),TEOX_4_H1LT)
plot(mean(H1LT_0deg_Vx),TEOX_5_H1LT)
plot(mean(H1LT_0deg_Vx),TEOX_6_H1LT)
legend off
for i = 1:8
    plot(H1LT_0deg_Vx(:,i),H1LT_0deg_Fx(:,i),'rx')
end
plot(mean(H1LT_0deg_Vx),mean(H1LT_0deg_Fx),'r-.')
legend('Experiment','$\hat{f}_1$','$\hat{f}_2$','$\hat{f}_3$','$\hat{f}_4$','$\hat{f}_5$','$\hat{f}_6$','location','best')
axis([0.1 0.85 -1 0])
xlabel('Velocity X [m/s]')
ylabel('Force X [N]')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\experiments\v1_0deg\sysid\sysid_0deg_h1lt.eps');
%% theta = 0, comp exp and sysid H2LT
f = f+1;
figure(f)
hold on
grid on
plot(H2LT_0deg_Vx(1,1),H2LT_0deg_Fx(1,1),'rx')
plot(mean(H2LT_0deg_Vx),TEOX_1_H2LT)
plot(mean(H2LT_0deg_Vx),TEOX_2_H2LT)
plot(mean(H2LT_0deg_Vx),TEOX_3_H2LT)
plot(mean(H2LT_0deg_Vx),TEOX_4_H2LT)
plot(mean(H2LT_0deg_Vx),TEOX_5_H2LT)
plot(mean(H2LT_0deg_Vx),TEOX_6_H2LT)
legend off
for i = 1:5
    plot(H2LT_0deg_Vx(:,i),H2LT_0deg_Fx(:,i),'rx')
end
plot(mean(H2LT_0deg_Vx),mean(H2LT_0deg_Fx),'r-.')
legend('Experiment','$\hat{f}_1$','$\hat{f}_2$','$\hat{f}_3$','$\hat{f}_4$','$\hat{f}_5$','$\hat{f}_6$')
axis([0.35 0.62 -inf -0.18])
xlabel('Velocity X [m/s]')
ylabel('Force X [N]')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\experiments\v1_0deg\sysid\sysid_0deg_h2lt.eps');